function v=compute_ekman_surge_bexp(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes ekman_surge_bexp
% Script automatically generated by fit_ekman_surge_bexp.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.85566
% RMSE  = 13.7856
% MEAN  = -19.9616
% RANGE = -117.4183 - 50.6394

beta( 1 )= -3.7707e+01 ;
beta( 2 )= 5.3777e-03 ;
beta( 3 )= 3.9180e-01 ;
beta( 4 )= 1.0036e+00 ;
beta( 5 )= -8.2190e-02 ;
beta( 6 )= -5.3051e-01 ;
beta( 7 )= 4.7017e+02 ;

v=beta(1) + beta(2)*w .* phi + beta(3)*vt + beta(4)*phi_in + beta(5).*w + beta(6).*lat + beta(7).*a;
